pub struct TreeNode {
pub left: u32,
pub right: u32,
pub height: u32,
pub padding: u32,
pub key: Entry,
pub value: Value,
}Fields
left: u32right: u32height: u32padding: u32key: Entryvalue: ValueTrait Implementations
Sourceimpl BorshDeserialize for TreeNode
impl BorshDeserialize for TreeNode
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TreeNode
impl BorshSerialize for TreeNode
impl Eq for TreeNode
impl StructuralPartialEq for TreeNode